==> haskell-barbies-2.0.4.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-barbies.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 barbies
version:              2.0.4.0
visibility:           public
id:                   barbies-2.0.4.0-JRrrEw8YtDrJbbERAc5Zvw
key:                  barbies-2.0.4.0-JRrrEw8YtDrJbbERAc5Zvw
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  05a704990a547575d4d9bd7a1dbbd310
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Barbie Data.Barbie.Bare
    Data.Barbie.Constraints Data.Functor.Barbie Data.Functor.Prod
    Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN Data.Barbie.Internal.Product
    Data.Barbie.Internal.ProductC

import-dirs:          /usr/lib/ghc-9.0.2/site-local/barbies-2.0.4.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/barbies-2.0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.0.4.0-JRrrEw8YtDrJbbERAc5Zvw
depends:
    base-4.15.1.0 distributive-0.6.2.1-F4pzAtG4GQrIKdAbD2ZDyZ
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-barbies-2.0.4.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-barbies.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 barbies
version:              2.0.4.0
visibility:           public
id:                   barbies-2.0.4.0-LPeMNZ7bdZ39HGlZYhuwLx
key:                  barbies-2.0.4.0-LPeMNZ7bdZ39HGlZYhuwLx
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  b906c79b4ea63a2a0eb1a728e6790ffd
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Barbie Data.Barbie.Bare
    Data.Barbie.Constraints Data.Functor.Barbie Data.Functor.Prod
    Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN Data.Barbie.Internal.Product
    Data.Barbie.Internal.ProductC

import-dirs:          /usr/lib/ghc-9.0.2/site-local/barbies-2.0.4.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/barbies-2.0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.0.4.0-LPeMNZ7bdZ39HGlZYhuwLx
depends:
    base-4.15.1.0 distributive-0.6.2.1-IMTpSSzBnx7LiUwDqfQ6mM
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
